import fetch from 'node-fetch';
import checkTargetUrl from './check-target-url';
import { REPLICATION_STATE } from '@resolve-js/module-replication';

const getReplicationState = async ({
  targetApplicationUrl
}) => {
  const checkResult = checkTargetUrl(targetApplicationUrl);

  if (checkResult != null) {
    return checkResult;
  }

  const defaultValues = {
    paused: false,
    iterator: null,
    successEvent: null,
    locked: false,
    lockId: null
  };

  try {
    const response = await fetch(`${targetApplicationUrl}${REPLICATION_STATE.endpoint}`);

    if (response.status >= 400) {
      return {
        statusAndData: {
          status: 'serviceError',
          data: {
            name: response.statusText,
            message: await response.text()
          }
        },
        ...defaultValues
      };
    }

    return await response.json();
  } catch (error) {
    if (error.name === 'AbortError' || error.name === 'FetchError' || error.name === 'TypeError') {
      return {
        statusAndData: {
          status: 'serviceError',
          data: {
            name: error.name,
            message: error.message
          }
        },
        ...defaultValues
      };
    } else {
      return {
        statusAndData: {
          status: 'criticalError',
          data: {
            name: error.name,
            message: error.message
          }
        },
        ...defaultValues
      };
    }
  }
};

export default getReplicationState;
//# sourceMappingURL=get-replication-state.js.map